.. _model_attributes:
.. currentmodule:: hydromt_wflow.wflow

Model attributes
================

A wflow model in HydroMT also has a set of specific attributes, on top of the ones 
from the model API. These are:

.. autosummary::
   :toctree: ../../generated/
   :nosignatures:

   ~WflowModel.flwdir
   ~WflowModel.basins
   ~WflowModel.rivers